
# IssuePrefix: test TOML config

*[ribbity-org/ribbity-test-repo#3](https://github.com/ribbity-org/ribbity-test-repo/issues/3)*

---

<!--
# toml config options below.
---
frontpage = true # should it show up on front page?
priority = 5 # default priority 999 => in with all the rest :). 1 pushes it to top, etc.
---
-->

this example should show up front page. has priority = 5.


